/*----------------------------------------------------------------------*\
 | CGI program to convert table to Enumerated_Domain elements			|
 |																		|
 | Peter N. Schweitzer (U.S. Geological Survey, Reston, VA 20192)		|
\*----------------------------------------------------------------------*/

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <ctype.h>
#include <time.h>

#include "formio.h"
#include "buffer.h"

/*----------------------------------------------------------------------*\
\*----------------------------------------------------------------------*/

static char header[] =
"<!-- BEGIN USGS Header Template -->"
"<div id=\"usgscolorband\">"
"	<div id=\"usgsbanner\">"
"		<div id=\"usgsidentifier\"><a href=\"https://www.usgs.gov/\"><img src=\"/images/header_graphic_usgsIdentifier_white.jpg\" alt=\"USGS - science for a changing world\" title=\"U.S. Geological Survey Home Page\" width=\"178\" height=\"72\" /></a></div>"
"		<div id=\"usgsccsabox\">"
"			<div id=\"usgsccsa\">"
"			  <br /><a href=\"https://www.usgs.gov/\">USGS Home</a>"
"			  <br /><a href=\"https://www.usgs.gov/ask/\">Contact USGS</a>"
"			  <br /><a href=\"https://search.usgs.gov/\">Search USGS</a>"
"			</div>"
"		</div>"
"	</div>"
"</div>"
"<div id=\"usgstitle\">"
"	<p>USGS Geoscience Data Catalog</p>"
"</div>"
"<!-- END USGS Header Template -->";

static char *maintainer_line = "Maintained by <a href=\"https://geology.usgs.gov/peter/\">Peter Schweitzer</a><br>";

static char *empty = "(empty)";

static char *default_delimiter = "tab";
static char *delimiter = NULL;
static char *other = NULL;
static char *stuff = NULL;

/*----------------------------------------------------------------------*\
\*----------------------------------------------------------------------*/

#ifndef HAVE_STRICMP

int stricmp (char *s, char *t) {
	int d = 0;
	do {
		d = toupper(*s) - toupper(*t);
		} while (*s++ && *t++ && !d);
	return (d);
	}

#endif

/*----------------------------------------------------------------------*\
\*----------------------------------------------------------------------*/

void decode_stuff (char *string) {
	if (string && *string) stuff = string;
	}

void decode_other (char *string) {
	if (string && *string) other = string;
	}

void decode_delimiter (char *string) {
	if (string && *string) delimiter = string;
	}

/*----------------------------------------------------------------------*/

struct keyword_table keyword[] = {
	{"stuff",		decode_stuff},
	{"other",		decode_other},
	{"delimiter",	decode_delimiter},
	{NULL,			NULL}
	};
static int keyword_count = 0;

/*----------------------------------------------------------------------*\
\*----------------------------------------------------------------------*/

main (int argc, char *argv[]) {
	char *b,*e,*s;
	char *value,*definition,*source;
	char d;

	get_form_input();

	printf ("Content-type: text/html\n");
	printf ("\n");

	printf ("<!DOCTYPE html>\n");
	printf ("<html>\n");
	printf ("<head>\n");
	printf ("  <title>");
	printf ("Enumerated_Domain helper results");
	printf ("</title>\n");
	printf ("  <link rel=\"stylesheet\" type=\"text/css\" href=\"/styles/common.css\">\n");
	printf ("  <link rel=\"stylesheet\" type=\"text/css\" href=\"/local.css\">\n");
	printf ("  <link rel=\"P3Pv1\" href=\"/w3c/p3p.xml\">\n");
	printf ("</head>\n");
	printf ("<body>\n");
	printf ("%s\n",header);

	printf ("<h1>Enumerated_Domain helper results</h1>\n");

	/* Clarify delimiter */

	if (!delimiter) {
		delimiter = default_delimiter;
		printf ("Delimiter assumed to be %s.<p>\n",default_delimiter);
		}

	if (stricmp (delimiter,"tab") == 0) d = '\t';
	else
		if (stricmp (delimiter,"space") == 0) d = ' ';
		else
			if (stricmp (delimiter,"colon") == 0) d = ':';
			else
				if (stricmp (delimiter,"equal") == 0) d = '=';
				else
					if (stricmp (delimiter,"hyphen") == 0) d = '-';
					else
						if (stricmp (delimiter,"other") == 0) d = *other;
						else
							d = '\t';

	/* Parse stuff */

	if (stuff) {
		printf ("Edit the text below to fix any mistakes, then select the text and paste into your metadata editor.<p>\n");
		printf ("<div style=\"margin: 1em;\">\n");
		printf ("<form method=\"POST\" action=\"/cgi-bin/dm/echo\">\n");
		printf ("<textarea name=\"results\" rows=\"30\" cols=\"80\" wrap=\"off\">\n");

		b = stuff;
		while (*b) {

			value = definition = source = NULL;

			/* Skip leading whitespace */

			while (*b && isspace(*b)) b++;

			/* Scan forward to the delimiter, EOL, or NUL */

			e = b;
			while (*e && *e != d && *e != '\n') e++;

			/* If you found the delimiter, look for definition */

			if (*e == d) {
				*e++ = 0;
				value = b;
				b = e;
				while (*b && isspace(*b)) b++;

				/* Scan forward to the delimiter, EOL, or NUL */

				e = b;
				while (*e && *e != d && *e != '\n') e++;
				if (*e == '\n') *e++ = 0;
				definition = b;

				/* If not EOL or NUL, a source is given on this line */

				if (*e == d) {
					*e++ = 0;
					b = e;
					while (*b && isspace(*b)) b++;
					e = b;
					while (*e && *e != '\n') e++;
					if (*e == '\n') *e++ = 0;
					source = b;
					}

				b = e;
				}
			else
				if (*e == '\n') {	/* EOL; no definition given */
					*e++ = 0;
					value = b;
					}
				else
					if (*b) value = b;	/* NUL; last value only */

			if (value) {
				printf ("Attribute_Domain_Values:\n");
				printf ("  Enumerated_Domain:\n");
				printf ("    Enumerated_Domain_Value: %s\n",entity_substitution (value));
				if (definition && *definition)
					printf ("    Enumerated_Domain_Value_Definition: %s\n",entity_substitution(definition));
				if (source && *source)
					printf ("    Enumerated_Domain_Value_Definition_Source: %s\n",entity_substitution(source));
				}
			value = definition = NULL;
			b = e;
			}

		printf ("</textarea>");
		printf ("</form>\n");
		printf ("</div>\n");
		}

	printf ("<!-- BEGIN USGS Footer Template -->\n");
	printf ("<div id=\"usgsfooter\">\n");
	printf ("	<p id=\"usgsfooterbar\">\n");
	printf ("		<a href=\"https://www2.usgs.gov/laws/accessibility.html\" title=\"Accessibility Policy (Section 508)\">Accessibility</a>\n");
	printf ("		<a href=\"https://www2.usgs.gov/foia/\" title=\"Freedom of Information Act\">FOIA</a>\n");
	printf ("		<a href=\"https://www2.usgs.gov/laws/privacy.html\" title=\"Privacy policies of the U.S. Geological Survey.\">Privacy</a>\n");
	printf ("		<a href=\"https://www2.usgs.gov/laws/policies_notices.html\" title=\"Policies and notices that govern information posted on USGS Web sites.\">Policies and Notices</a>\n");
	printf ("	</p>\n");

	printf ("	<p id=\"usgsfootertext\">\n");
	printf ("		<a href=\"https://usa.gov/\"><img src=\"http://www.usgs.gov/images/footer_graphic_usagov.jpg\" alt=\"USA.gov logo\" title=\"USA.gov: Government made easy\" width=\"90\" height=\"26\" /></a>\n");
	printf ("		<a href=\"https://www.doi.gov/\">U.S. Department of the Interior</a> |\n");
	printf ("		<a href=\"https://www.usgs.gov/\">U.S. Geological Survey</a><br />\n");
	printf ("		Page Contact Information: <a href=\"https://geology.usgs.gov/peter/\">Peter Schweitzer</a><br/>\n");
	printf ("	</p>\n");
	printf ("</div>\n");
	printf ("<!-- END USGS Footer Template -->\n");

	printf ("</body>\n");
	printf ("</html>\n");
	}

/*----------------------------------------------------------------------*\
\*----------------------------------------------------------------------*/
